@@ -19,6 +19,7 @@ from pandas.util.testing import (assert_series_equal,
                                  makeCustomDataframe as mkdf)
 
 import pandas.util.testing as tm
+from pandas.computation import _NUMEXPR_INSTALLED
 
 from pandas.tests.frame.common import TestData
 
@@ -34,13 +35,59 @@ def skip_if_no_pandas_parser(parser):
 
 def skip_if_no_ne(engine='numexpr'):
     if engine == 'numexpr':
-        try:
-            import numexpr as ne  # noqa
-        except ImportError:
+        if not _NUMEXPR_INSTALLED:
             raise nose.SkipTest("cannot query engine numexpr when numexpr not "
                                 "installed")
 
 
+class TestCompat(tm.TestCase):
+
+    def setUp(self):
+        self.df = DataFrame({'A': [1, 2, 3]})
+        self.expected1 = self.df[self.df.A > 0]
+        self.expected2 = self.df.A + 1
+
+    def test_query_default(self):
+
+        # GH 12749
+        # this should always work, whether _NUMEXPR_INSTALLED or not
+        df = self.df
+        result = df.query('A>0')
+        assert_frame_equal(result, self.expected1)
+        result = df.eval('A+1')
+        assert_series_equal(result, self.expected2, check_names=False)
+
+    def test_query_None(self):
+
+        df = self.df
+        result = df.query('A>0', engine=None)
+        assert_frame_equal(result, self.expected1)
+        result = df.eval('A+1', engine=None)
+        assert_series_equal(result, self.expected2, check_names=False)
+
+    def test_query_python(self):
+
+        df = self.df
+        result = df.query('A>0', engine='python')
+        assert_frame_equal(result, self.expected1)
+        result = df.eval('A+1', engine='python')
+        assert_series_equal(result, self.expected2, check_names=False)
+
+    def test_query_numexpr(self):
+
+        df = self.df
+        if _NUMEXPR_INSTALLED:
+            result = df.query('A>0', engine='numexpr')
+            assert_frame_equal(result, self.expected1)
+            result = df.eval('A+1', engine='numexpr')
+            assert_series_equal(result, self.expected2, check_names=False)
+        else:
+            self.assertRaises(ImportError,
+                              lambda: df.query('A>0', engine='numexpr'))
+            self.assertRaises(ImportError,
+                              lambda: df.eval('A+1', engine='numexpr'))
+
+
 class TestDataFrameEval(tm.TestCase, TestData):
 
     _multiprocess_can_split_ = True
@@ -89,6 +136,35 @@ class TestDataFrameEval(tm.TestCase, TestData):
         result = (1 - np.isnan(df)).iloc[0:25]
         assert_frame_equal(result, expected)
 
+    def test_query_non_str(self):
+        # GH 11485
+        df = pd.DataFrame({'A': [1, 2, 3], 'B': ['a', 'b', 'b']})
+
+        msg = "expr must be a string to be evaluated"
+        with tm.assertRaisesRegexp(ValueError, msg):
+            df.query(lambda x: x.B == "b")
+
+        with tm.assertRaisesRegexp(ValueError, msg):
+            df.query(111)
+
+    def test_query_empty_string(self):
+        # GH 13139
+        df = pd.DataFrame({'A': [1, 2, 3]})
+
+        msg = "expr cannot be an empty string"
+        with tm.assertRaisesRegexp(ValueError, msg):
+            df.query('')
+
+    def test_eval_resolvers_as_list(self):
+        # GH 14095
+        df = DataFrame(randn(10, 2), columns=list('ab'))
+        dict1 = {'a': 1}
+        dict2 = {'b': 2}
+        self.assertTrue(df.eval('a + b', resolvers=[dict1, dict2]) ==
+                        dict1['a'] + dict2['b'])
+        self.assertTrue(pd.eval('a + b', resolvers=[dict1, dict2]) ==
+                        dict1['a'] + dict2['b'])
+
 
 class TestDataFrameQueryWithMultiIndex(tm.TestCase):
 
@@ -1048,8 +1124,8 @@ class TestDataFrameEvalNumExprPandas(tm.TestCase):
         ops = '+', '-', '*', '/'
         for op in ops:
             with tm.assertRaisesRegexp(TypeError,
-                                       "unsupported operand type\(s\) for "
-                                       ".+: '.+' and '.+'"):
+                                       r"unsupported operand type\(s\) for "
+                                       r".+: '.+' and '.+'"):
                 df.eval('a {0} b'.format(op), engine=self.engine,
                         parser=self.parser)
 
